@@ -6,7 +6,7 @@ use warnings;
 
 use Carp;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 our $debug = $ENV{DICE_ROLLER_DEBUG} // 0;
 
 sub new{
@@ -396,26 +396,8 @@ sub _identify_type{
 	}	
 }
 
-my $wanted=<<'EOT';
-
-#########################
-# multiple dice expression:
-#########################
-Dice pools; {2d8, 1d6}						(qw( 2d8   1d6 )) 		-> sum
-Dice pools with modifiers; {1d20+7, 10}kh1	(qw( 2d8+7 1d20 ))
-											(qw( 2d8+7 33 ))
-											(qw( 2d8 1d6 kh ))
-											(qw( 2d8 1d6 kl ))
-											(qw( 2d8 33 kh ))
-											(qw( 2d8 33 kl ))
-
-
-Rounding; floor(1.5), ceil(1.5), round(1.5)
-Average; avg(8d6)
-
-
-EOT
 
+1; # End of Module
 
 
 =head1 NAME
@@ -519,7 +501,7 @@ In the descriptive string some die result can be modified by modifiers: dropped
 
 A third element is returned too: a hash reference intended to be used mainly internally and for debug purposes, with the internal carateristics of the dice expression. Dont rely on this because it can be changed or removed in future releases.
 
-=head3 die mofiers
+=head3 die modifiers
 
 =head4 avg - average
 
@@ -649,13 +631,6 @@ You can also look for information at:
 
 L<https://rt.cpan.org/NoAuth/Bugs.html?Dist=Games-Dice-Roller>
 
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Games-Dice-Roller>
-
-=item * CPAN Ratings
-
-L<https://cpanratings.perl.org/d/Games-Dice-Roller>
 
 =item * Search CPAN
 
@@ -709,5 +684,3 @@ EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 =cut
-
-1; # End of Module
\ No newline at end of file
